@@ -7,7 +7,11 @@ __appname__ = "Labelme"
 # 2. MINOR version when you add functionality in a backwards-compatible manner;
 # 3. PATCH version when you make backwards-compatible bug fixes.
 # e.g., 1.0.0a0, 1.0.0a1, 1.0.0b0, 1.0.0rc0, 1.0.0, 1.0.0.post0
-__version__ = "5.10.0"
+__version__ = "5.10.1"
+
+# XXX: has to be imported before PyQt5 to load dlls in order on Windows
+# https://github.com/wkentaro/labelme/issues/1564
+import onnxruntime
 
 from labelme import testing
 from labelme import utils
